"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.bindAgileInstances = void 0;
const core_1 = require("@agile-ts/core");
const utils_1 = require("@agile-ts/utils");
function bindAgileInstances(deps, agile, vueComponent) {
    let depsWithoutIndicator = [];
    let depsWithIndicator;
    if (utils_1.isValidObject(deps)) {
        depsWithIndicator = formatDepsWithIndicator(deps);
    }
    else {
        const response = formatDepsWithNoSafeIndicator(deps);
        depsWithIndicator = response.depsWithIndicator;
        depsWithoutIndicator = response.depsWithoutIndicator;
    }
    if (depsWithoutIndicator.length > 0) {
        agile.subController.subscribeWithSubsArray(vueComponent, depsWithoutIndicator, { waitForMount: false });
    }
    if (depsWithIndicator) {
        return agile.subController.subscribeWithSubsObject(vueComponent, depsWithIndicator, { waitForMount: false }).props;
    }
    return {};
}
exports.bindAgileInstances = bindAgileInstances;
const formatDepsWithNoSafeIndicator = (deps) => {
    const depsArray = core_1.extractObservers(deps);
    const depsWithIndicator = {};
    let depsWithoutIndicator = depsArray.filter((dep) => dep !== undefined);
    depsWithoutIndicator = depsWithoutIndicator.filter((dep) => {
        if (dep && dep['key']) {
            depsWithIndicator[dep['key']] = dep;
            return false;
        }
        return true;
    });
    return {
        depsWithIndicator,
        depsWithoutIndicator,
    };
};
const formatDepsWithIndicator = (deps) => {
    const depsWithIndicator = {};
    for (const depKey in deps) {
        const observer = core_1.extractObservers(deps[depKey])[0];
        if (observer)
            depsWithIndicator[depKey] = observer;
    }
    return depsWithIndicator;
};
